@@ -1,6 +1,8 @@
 import time
-from squad.core.models import Group, Project, TestRun
+from squad.core.models import Group
 from squad.ci.models import Backend
+from squad.ci.tasks import fetch
+from squad.ci.utils import task_id
 from django.core.management.base import BaseCommand
 
 
@@ -8,6 +10,12 @@ class Command(BaseCommand):
     help = """Listens for "live" test results from CI backends"""
 
     def add_arguments(self, parser):
+        parser.add_argument(
+            '--background', '-b',
+            action='store_true',
+            dest="background",
+            help="Fetch in the background (requires a running worker)",
+        )
         parser.add_argument(
             'BACKEND',
             type=str,
@@ -35,6 +43,9 @@ class Command(BaseCommand):
         project, _ = group.projects.get_or_create(slug=project_slug)
         build = project.builds.create(version=str(time.time()))
 
-        testjob = backend.test_jobs.create(target=project, job_id=job_id, build=build.version)
+        testjob = backend.test_jobs.create(target=project, job_id=job_id, target_build=build)
 
-        backend.fetch(testjob)
+        if options.get("background"):
+            fetch.apply_async(args=(testjob.id,), task_id=task_id(testjob))
+        else:
+            backend.fetch(testjob.id)
