@@ -10,15 +10,16 @@ job_status = 'Finished'
 completed = True
 metadata = {'foo': 'bar'}
 tests = {'test1': 'pass'}
-metrics = {'metric1': 1}
+metrics = {'metric1': {"value": 1, "unit": ""}}
 logs = "hello world\nfinished\n"
 
 
 class BuildNotificationFromCI(TestCase):
 
     @patch('squad.core.tasks.maybe_notify_project_status')
+    @patch('squad.ci.backend.null.Backend.job_url', return_value="http://example.com/123")
     @patch('squad.ci.backend.null.Backend.fetch')
-    def test_fetch_triggers_notification(self, fetch, notify):
+    def test_fetch_triggers_notification(self, fetch, job_url, notify):
         fetch.return_value = (job_status, completed, metadata, tests, metrics, logs)
 
         group = Group.objects.create(slug='mygroup')
@@ -33,11 +34,12 @@ class BuildNotificationFromCI(TestCase):
         )
         testjob = backend.test_jobs.create(
             target=project,
-            build='1',
+            target_build=build,
             job_id='123',
             environment='myenv',
         )
-        backend.fetch(testjob)
+        backend.fetch(testjob.id)
         status = build.status
+        status.refresh_from_db()
         notify.delay.assert_called_with(status.id)
         self.assertTrue(status.finished)
